﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Csla;
using Csla.Serialization;
//using MyCSLA;
//using System.Data;
//using System.Data.SqlClient;
using Csla.Data;

namespace Library.Rapport.Samling
{
    /// <summary>
    /// RapportHead
    /// </summary>
    [Serializable]
    public class RapportHead : BusinessBase<RapportHead>
    {

        public enum RapportHead_RAPType
        {
            IkkeValgt = 0,
            ActiveReports = 1,
            SearchObject = 2,
            Link = 3,
            Excel = 4
        }

        #region " Business Properties and Methods "

        private static readonly PropertyInfo<int> RAPRecProperty = RegisterProperty<int>(p => p.RAPRec, "Rec");
        /// <summary>
        /// Unikt rekordnummer for tabellen RapportHead
        /// </summary>
        public int RAPRec
        {
            get { return GetProperty(RAPRecProperty); }
            set { SetProperty(RAPRecProperty, value); }
        }

        private static readonly PropertyInfo<RapportHead_RAPType> RAPTypeProperty = RegisterProperty<RapportHead_RAPType>(p => p.RAPType, "RAPType");
        /// <summary>
        /// Rapport type
        /// </summary>
        public RapportHead_RAPType RAPType
        {
            get { return GetProperty(RAPTypeProperty); }
            set { SetProperty(RAPTypeProperty, value); }
        }

        private static readonly PropertyInfo<string> RAPNavnProperty = RegisterProperty<string>(p => p.RAPNavn, "RAPNavn");
        /// <summary>
        /// Rapport navn
        /// </summary>
        public string RAPNavn
        {
            get { return GetProperty(RAPNavnProperty); }
            set { SetProperty(RAPNavnProperty, value); }
        }

        private static readonly PropertyInfo<string> RAPReportObjProperty = RegisterProperty<string>(p => p.RAPReportObj, "RAPReportObj");
        /// <summary>
        /// Json rapport oppsett
        /// </summary>
        public string RAPReportObj
        {
            get { return GetProperty(RAPReportObjProperty); }
            set { SetProperty(RAPReportObjProperty, value); }
        }

        private static readonly PropertyInfo<string> RAPLinkProperty = RegisterProperty<string>(p => p.RAPLink, "RAPLink");
        /// <summary>
        /// Link til rapport. 
        /// </summary>
        public string RAPLink
        {
            get { return GetProperty(RAPLinkProperty); }
            set { SetProperty(RAPLinkProperty, value); }
        }

        private static readonly PropertyInfo<string> RAPBeskrivelseProperty = RegisterProperty<string>(p => p.RAPBeskrivelse, "RAPBeskrivelse");
        /// <summary>
        /// Beskrivelse
        /// </summary>
        public string RAPBeskrivelse
        {
            get { return GetProperty(RAPBeskrivelseProperty); }
            set { SetProperty(RAPBeskrivelseProperty, value); }
        }

        private static readonly PropertyInfo<string> RAPStikkordProperty = RegisterProperty<string>(p => p.RAPStikkord, "RAPStikkord");
        /// <summary>
        /// Beskrivelse
        /// </summary>
        public string RAPStikkord
        {
            get { return GetProperty(RAPStikkordProperty); }
            set { SetProperty(RAPStikkordProperty, value); }
        }

        private static readonly PropertyInfo<string> RAPLagetAvProperty = RegisterProperty<string>(p => p.RAPLagetAv, "RAPLagetAv");
        /// <summary>
        /// Hvem som har laget rapporten
        /// </summary>
        public string RAPLagetAv
        {
            get { return GetProperty(RAPLagetAvProperty); }
            set { SetProperty(RAPLagetAvProperty, value); }
        }

        private static readonly PropertyInfo<bool> RAPAktivProperty = RegisterProperty<bool>(p => p.RAPAktiv, "RAPAktiv", false);
        /// <summary>
        /// Aktive rapporter vises i listen til brukerne.
        /// </summary>
        public bool RAPAktiv
        {
            get { return GetProperty(RAPAktivProperty); }
            set { SetProperty(RAPAktivProperty, value); }
        }

        private static readonly PropertyInfo<bool> RAPGodkjentProperty = RegisterProperty<bool>(p => p.RAPGodkjent, "RAPGodkjent", false);
        /// <summary>
        /// Godkjent rapport er sjekket at den gir riktige tall.
        /// </summary>
        public bool RAPGodkjent
        {
            get { return GetProperty(RAPGodkjentProperty); }
            set { SetProperty(RAPGodkjentProperty, value); }
        }

        private static readonly PropertyInfo<int> RAPPriorityProperty = RegisterProperty<int>(p => p.RAPPriority, "RAPPriority", 0);
        /// <summary>
        /// Prioritet. Default=0. Høyest nummer kommer på toppen av listen.
        /// </summary>
        public int RAPPriority
        {
            get { return GetProperty(RAPPriorityProperty); }
            set { SetProperty(RAPPriorityProperty, value); }
        }

        private static readonly PropertyInfo<byte[]> LastChangedProperty = RegisterProperty<byte[]>(p => p.LastChanged, "LastChanged");
        /// <summary>
        /// Timestamp for siste endring
        /// </summary>
        public byte[] LastChanged
        {
            get { return ReadProperty(LastChangedProperty); }
            internal set { SetProperty(LastChangedProperty, value); }
        }

        #endregion


        #region " dataportal events "

        protected override void DataPortal_OnDataPortalInvoke(DataPortalEventArgs e)
        {
            // implement your behavior here
            base.DataPortal_OnDataPortalInvoke(e);
        }

        protected override void DataPortal_OnDataPortalInvokeComplete(DataPortalEventArgs e)
        {
            // implement your behavior here
            base.DataPortal_OnDataPortalInvokeComplete(e);
        }

        protected override void Child_OnDataPortalException(DataPortalEventArgs e, Exception ex)
        {
            // implement your behavior here
            base.Child_OnDataPortalException(e, ex);
        }

        #endregion

        #region " Factory Methods "

        /// <summary>
        /// Oppretter tomt RapportHead objekt
        /// </summary>
        /// <returns></returns>
        public static RapportHead NewRapportHead()
        {
            return DataPortal.Create<RapportHead>();
        }

        /// <summary>
        /// Henter RapportHead objekt med gitt rekordnummer
        /// </summary>
        /// <param name="RAPRec"></param>
        /// <returns></returns>
        public static RapportHead GetRapportHead(int RAPRec)
        {
            return DataPortal.Fetch<RapportHead>(RAPRec);
        }

        /// <summary>
        /// Sletter RapportHead med gitt rekordnummer
        /// </summary>
        /// <param name="RAPRec"></param>
        public static void DeleteRapportHead(int RAPRec)
        {
            DataPortal.Delete<RapportHead>(RAPRec);
        }


        #endregion

        #region " Data Access - Create "

        [RunLocal]
        protected override void DataPortal_Create()
        {
            using (BypassPropertyChecks)
            {
                ExecuteCreate();
            }
            BusinessRules.CheckRules();
        }

        /// <summary>
        /// Setter standardverdier for klassen
        /// </summary>
        private void ExecuteCreate()
        {
            //  this.FSSone = NextNumber();
            base.DataPortal_Create();
        }

        #endregion

    }

}

